# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetsStatusCountChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'normal': 'int',
        'warning': 'int',
        'alarm': 'int'
    }

    attribute_map = {
        'normal': 'Normal',
        'warning': 'Warning',
        'alarm': 'Alarm'
    }

    def __init__(self, normal=None, warning=None, alarm=None):  # noqa: E501
        """AssetsStatusCountChild - a model defined in Swagger"""  # noqa: E501
        self._normal = None
        self._warning = None
        self._alarm = None
        self.discriminator = None
        self.normal = normal
        self.warning = warning
        self.alarm = alarm

    @property
    def normal(self):
        """Gets the normal of this AssetsStatusCountChild.  # noqa: E501


        :return: The normal of this AssetsStatusCountChild.  # noqa: E501
        :rtype: int
        """
        return self._normal

    @normal.setter
    def normal(self, normal):
        """Sets the normal of this AssetsStatusCountChild.


        :param normal: The normal of this AssetsStatusCountChild.  # noqa: E501
        :type: int
        """
        if normal is None:
            raise ValueError("Invalid value for `normal`, must not be `None`")  # noqa: E501

        self._normal = normal

    @property
    def warning(self):
        """Gets the warning of this AssetsStatusCountChild.  # noqa: E501


        :return: The warning of this AssetsStatusCountChild.  # noqa: E501
        :rtype: int
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """Sets the warning of this AssetsStatusCountChild.


        :param warning: The warning of this AssetsStatusCountChild.  # noqa: E501
        :type: int
        """
        if warning is None:
            raise ValueError("Invalid value for `warning`, must not be `None`")  # noqa: E501

        self._warning = warning

    @property
    def alarm(self):
        """Gets the alarm of this AssetsStatusCountChild.  # noqa: E501


        :return: The alarm of this AssetsStatusCountChild.  # noqa: E501
        :rtype: int
        """
        return self._alarm

    @alarm.setter
    def alarm(self, alarm):
        """Sets the alarm of this AssetsStatusCountChild.


        :param alarm: The alarm of this AssetsStatusCountChild.  # noqa: E501
        :type: int
        """
        if alarm is None:
            raise ValueError("Invalid value for `alarm`, must not be `None`")  # noqa: E501

        self._alarm = alarm

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetsStatusCountChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetsStatusCountChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WidgetTemplateFilterChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter_data_field_code': 'str',
        'filter_data_field_name': 'str',
        'filter_operator': 'str',
        'filter_value': 'str'
    }

    attribute_map = {
        'filter_data_field_code': 'FilterDataFieldCode',
        'filter_data_field_name': 'FilterDataFieldName',
        'filter_operator': 'FilterOperator',
        'filter_value': 'FilterValue'
    }

    def __init__(self, filter_data_field_code=None, filter_data_field_name=None, filter_operator=None, filter_value=None):  # noqa: E501
        """WidgetTemplateFilterChild - a model defined in Swagger"""  # noqa: E501
        self._filter_data_field_code = None
        self._filter_data_field_name = None
        self._filter_operator = None
        self._filter_value = None
        self.discriminator = None
        self.filter_data_field_code = filter_data_field_code
        self.filter_data_field_name = filter_data_field_name
        self.filter_operator = filter_operator
        self.filter_value = filter_value

    @property
    def filter_data_field_code(self):
        """Gets the filter_data_field_code of this WidgetTemplateFilterChild.  # noqa: E501


        :return: The filter_data_field_code of this WidgetTemplateFilterChild.  # noqa: E501
        :rtype: str
        """
        return self._filter_data_field_code

    @filter_data_field_code.setter
    def filter_data_field_code(self, filter_data_field_code):
        """Sets the filter_data_field_code of this WidgetTemplateFilterChild.


        :param filter_data_field_code: The filter_data_field_code of this WidgetTemplateFilterChild.  # noqa: E501
        :type: str
        """
        if filter_data_field_code is None:
            raise ValueError("Invalid value for `filter_data_field_code`, must not be `None`")  # noqa: E501

        self._filter_data_field_code = filter_data_field_code

    @property
    def filter_data_field_name(self):
        """Gets the filter_data_field_name of this WidgetTemplateFilterChild.  # noqa: E501


        :return: The filter_data_field_name of this WidgetTemplateFilterChild.  # noqa: E501
        :rtype: str
        """
        return self._filter_data_field_name

    @filter_data_field_name.setter
    def filter_data_field_name(self, filter_data_field_name):
        """Sets the filter_data_field_name of this WidgetTemplateFilterChild.


        :param filter_data_field_name: The filter_data_field_name of this WidgetTemplateFilterChild.  # noqa: E501
        :type: str
        """
        if filter_data_field_name is None:
            raise ValueError("Invalid value for `filter_data_field_name`, must not be `None`")  # noqa: E501

        self._filter_data_field_name = filter_data_field_name

    @property
    def filter_operator(self):
        """Gets the filter_operator of this WidgetTemplateFilterChild.  # noqa: E501


        :return: The filter_operator of this WidgetTemplateFilterChild.  # noqa: E501
        :rtype: str
        """
        return self._filter_operator

    @filter_operator.setter
    def filter_operator(self, filter_operator):
        """Sets the filter_operator of this WidgetTemplateFilterChild.


        :param filter_operator: The filter_operator of this WidgetTemplateFilterChild.  # noqa: E501
        :type: str
        """
        if filter_operator is None:
            raise ValueError("Invalid value for `filter_operator`, must not be `None`")  # noqa: E501

        self._filter_operator = filter_operator

    @property
    def filter_value(self):
        """Gets the filter_value of this WidgetTemplateFilterChild.  # noqa: E501


        :return: The filter_value of this WidgetTemplateFilterChild.  # noqa: E501
        :rtype: str
        """
        return self._filter_value

    @filter_value.setter
    def filter_value(self, filter_value):
        """Sets the filter_value of this WidgetTemplateFilterChild.


        :param filter_value: The filter_value of this WidgetTemplateFilterChild.  # noqa: E501
        :type: str
        """
        if filter_value is None:
            raise ValueError("Invalid value for `filter_value`, must not be `None`")  # noqa: E501

        self._filter_value = filter_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WidgetTemplateFilterChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WidgetTemplateFilterChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HubReportResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'serial_number': 'str',
        'firmware_version': 'str',
        'hardware_revision': 'HardwareRevisionChild',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'power_type': 'HubPowerType',
        'number_of_ports': 'int',
        'triggering_enabled': 'bool',
        'reporting_node_total': 'int',
        'is_online': 'bool',
        'last_update_time': 'datetime'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'serial_number': 'SerialNumber',
        'firmware_version': 'FirmwareVersion',
        'hardware_revision': 'HardwareRevision',
        'location': 'Location',
        'corporation': 'Corporation',
        'power_type': 'PowerType',
        'number_of_ports': 'NumberOfPorts',
        'triggering_enabled': 'TriggeringEnabled',
        'reporting_node_total': 'ReportingNodeTotal',
        'is_online': 'IsOnline',
        'last_update_time': 'LastUpdateTime'
    }

    def __init__(self, id=None, name=None, serial_number=None, firmware_version=None, hardware_revision=None, location=None, corporation=None, power_type=None, number_of_ports=None, triggering_enabled=None, reporting_node_total=None, is_online=None, last_update_time=None):  # noqa: E501
        """HubReportResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._serial_number = None
        self._firmware_version = None
        self._hardware_revision = None
        self._location = None
        self._corporation = None
        self._power_type = None
        self._number_of_ports = None
        self._triggering_enabled = None
        self._reporting_node_total = None
        self._is_online = None
        self._last_update_time = None
        self.discriminator = None
        self.id = id
        if name is not None:
            self.name = name
        self.serial_number = serial_number
        if firmware_version is not None:
            self.firmware_version = firmware_version
        if hardware_revision is not None:
            self.hardware_revision = hardware_revision
        self.location = location
        self.corporation = corporation
        if power_type is not None:
            self.power_type = power_type
        if number_of_ports is not None:
            self.number_of_ports = number_of_ports
        self.triggering_enabled = triggering_enabled
        if reporting_node_total is not None:
            self.reporting_node_total = reporting_node_total
        if is_online is not None:
            self.is_online = is_online
        if last_update_time is not None:
            self.last_update_time = last_update_time

    @property
    def id(self):
        """Gets the id of this HubReportResponse.  # noqa: E501

        Id of the hub  # noqa: E501

        :return: The id of this HubReportResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HubReportResponse.

        Id of the hub  # noqa: E501

        :param id: The id of this HubReportResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this HubReportResponse.  # noqa: E501

        Name of the hub  # noqa: E501

        :return: The name of this HubReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HubReportResponse.

        Name of the hub  # noqa: E501

        :param name: The name of this HubReportResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def serial_number(self):
        """Gets the serial_number of this HubReportResponse.  # noqa: E501

        Serial number of the hub  # noqa: E501

        :return: The serial_number of this HubReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this HubReportResponse.

        Serial number of the hub  # noqa: E501

        :param serial_number: The serial_number of this HubReportResponse.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def firmware_version(self):
        """Gets the firmware_version of this HubReportResponse.  # noqa: E501

        firmware version of the hub  # noqa: E501

        :return: The firmware_version of this HubReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._firmware_version

    @firmware_version.setter
    def firmware_version(self, firmware_version):
        """Sets the firmware_version of this HubReportResponse.

        firmware version of the hub  # noqa: E501

        :param firmware_version: The firmware_version of this HubReportResponse.  # noqa: E501
        :type: str
        """

        self._firmware_version = firmware_version

    @property
    def hardware_revision(self):
        """Gets the hardware_revision of this HubReportResponse.  # noqa: E501


        :return: The hardware_revision of this HubReportResponse.  # noqa: E501
        :rtype: HardwareRevisionChild
        """
        return self._hardware_revision

    @hardware_revision.setter
    def hardware_revision(self, hardware_revision):
        """Sets the hardware_revision of this HubReportResponse.


        :param hardware_revision: The hardware_revision of this HubReportResponse.  # noqa: E501
        :type: HardwareRevisionChild
        """

        self._hardware_revision = hardware_revision

    @property
    def location(self):
        """Gets the location of this HubReportResponse.  # noqa: E501


        :return: The location of this HubReportResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this HubReportResponse.


        :param location: The location of this HubReportResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this HubReportResponse.  # noqa: E501


        :return: The corporation of this HubReportResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this HubReportResponse.


        :param corporation: The corporation of this HubReportResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def power_type(self):
        """Gets the power_type of this HubReportResponse.  # noqa: E501


        :return: The power_type of this HubReportResponse.  # noqa: E501
        :rtype: HubPowerType
        """
        return self._power_type

    @power_type.setter
    def power_type(self, power_type):
        """Sets the power_type of this HubReportResponse.


        :param power_type: The power_type of this HubReportResponse.  # noqa: E501
        :type: HubPowerType
        """

        self._power_type = power_type

    @property
    def number_of_ports(self):
        """Gets the number_of_ports of this HubReportResponse.  # noqa: E501

        The number of ports available.  A single sensor can report to a single port on a Hub.  # noqa: E501

        :return: The number_of_ports of this HubReportResponse.  # noqa: E501
        :rtype: int
        """
        return self._number_of_ports

    @number_of_ports.setter
    def number_of_ports(self, number_of_ports):
        """Sets the number_of_ports of this HubReportResponse.

        The number of ports available.  A single sensor can report to a single port on a Hub.  # noqa: E501

        :param number_of_ports: The number_of_ports of this HubReportResponse.  # noqa: E501
        :type: int
        """

        self._number_of_ports = number_of_ports

    @property
    def triggering_enabled(self):
        """Gets the triggering_enabled of this HubReportResponse.  # noqa: E501

        Is hub triggering enabled  # noqa: E501

        :return: The triggering_enabled of this HubReportResponse.  # noqa: E501
        :rtype: bool
        """
        return self._triggering_enabled

    @triggering_enabled.setter
    def triggering_enabled(self, triggering_enabled):
        """Sets the triggering_enabled of this HubReportResponse.

        Is hub triggering enabled  # noqa: E501

        :param triggering_enabled: The triggering_enabled of this HubReportResponse.  # noqa: E501
        :type: bool
        """
        if triggering_enabled is None:
            raise ValueError("Invalid value for `triggering_enabled`, must not be `None`")  # noqa: E501

        self._triggering_enabled = triggering_enabled

    @property
    def reporting_node_total(self):
        """Gets the reporting_node_total of this HubReportResponse.  # noqa: E501

        The number of nodes currently reporting to the hub.  # noqa: E501

        :return: The reporting_node_total of this HubReportResponse.  # noqa: E501
        :rtype: int
        """
        return self._reporting_node_total

    @reporting_node_total.setter
    def reporting_node_total(self, reporting_node_total):
        """Sets the reporting_node_total of this HubReportResponse.

        The number of nodes currently reporting to the hub.  # noqa: E501

        :param reporting_node_total: The reporting_node_total of this HubReportResponse.  # noqa: E501
        :type: int
        """

        self._reporting_node_total = reporting_node_total

    @property
    def is_online(self):
        """Gets the is_online of this HubReportResponse.  # noqa: E501

        Online state of the hub  # noqa: E501

        :return: The is_online of this HubReportResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_online

    @is_online.setter
    def is_online(self, is_online):
        """Sets the is_online of this HubReportResponse.

        Online state of the hub  # noqa: E501

        :param is_online: The is_online of this HubReportResponse.  # noqa: E501
        :type: bool
        """

        self._is_online = is_online

    @property
    def last_update_time(self):
        """Gets the last_update_time of this HubReportResponse.  # noqa: E501

        Last update time of the hub  # noqa: E501

        :return: The last_update_time of this HubReportResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this HubReportResponse.

        Last update time of the hub  # noqa: E501

        :param last_update_time: The last_update_time of this HubReportResponse.  # noqa: E501
        :type: datetime
        """

        self._last_update_time = last_update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HubReportResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubReportResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HubPortChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hub_port_id': 'int',
        'hub_port_number': 'int',
        'hub_port_node': 'HubNodeChild'
    }

    attribute_map = {
        'hub_port_id': 'HubPortId',
        'hub_port_number': 'HubPortNumber',
        'hub_port_node': 'HubPortNode'
    }

    def __init__(self, hub_port_id=None, hub_port_number=None, hub_port_node=None):  # noqa: E501
        """HubPortChild - a model defined in Swagger"""  # noqa: E501
        self._hub_port_id = None
        self._hub_port_number = None
        self._hub_port_node = None
        self.discriminator = None
        self.hub_port_id = hub_port_id
        self.hub_port_number = hub_port_number
        if hub_port_node is not None:
            self.hub_port_node = hub_port_node

    @property
    def hub_port_id(self):
        """Gets the hub_port_id of this HubPortChild.  # noqa: E501


        :return: The hub_port_id of this HubPortChild.  # noqa: E501
        :rtype: int
        """
        return self._hub_port_id

    @hub_port_id.setter
    def hub_port_id(self, hub_port_id):
        """Sets the hub_port_id of this HubPortChild.


        :param hub_port_id: The hub_port_id of this HubPortChild.  # noqa: E501
        :type: int
        """
        if hub_port_id is None:
            raise ValueError("Invalid value for `hub_port_id`, must not be `None`")  # noqa: E501

        self._hub_port_id = hub_port_id

    @property
    def hub_port_number(self):
        """Gets the hub_port_number of this HubPortChild.  # noqa: E501


        :return: The hub_port_number of this HubPortChild.  # noqa: E501
        :rtype: int
        """
        return self._hub_port_number

    @hub_port_number.setter
    def hub_port_number(self, hub_port_number):
        """Sets the hub_port_number of this HubPortChild.


        :param hub_port_number: The hub_port_number of this HubPortChild.  # noqa: E501
        :type: int
        """
        if hub_port_number is None:
            raise ValueError("Invalid value for `hub_port_number`, must not be `None`")  # noqa: E501

        self._hub_port_number = hub_port_number

    @property
    def hub_port_node(self):
        """Gets the hub_port_node of this HubPortChild.  # noqa: E501


        :return: The hub_port_node of this HubPortChild.  # noqa: E501
        :rtype: HubNodeChild
        """
        return self._hub_port_node

    @hub_port_node.setter
    def hub_port_node(self, hub_port_node):
        """Sets the hub_port_node of this HubPortChild.


        :param hub_port_node: The hub_port_node of this HubPortChild.  # noqa: E501
        :type: HubNodeChild
        """

        self._hub_port_node = hub_port_node

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HubPortChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubPortChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardWidgetChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dashboard_widget_id': 'str',
        'dashboard_widget_name': 'str',
        'dashboard_widget_refresh_interval': 'int',
        'dashboard_widget_layout': 'LayoutChild',
        'widget': 'WidgetChild'
    }

    attribute_map = {
        'dashboard_widget_id': 'DashboardWidgetId',
        'dashboard_widget_name': 'DashboardWidgetName',
        'dashboard_widget_refresh_interval': 'DashboardWidgetRefreshInterval',
        'dashboard_widget_layout': 'DashboardWidgetLayout',
        'widget': 'Widget'
    }

    def __init__(self, dashboard_widget_id=None, dashboard_widget_name=None, dashboard_widget_refresh_interval=None, dashboard_widget_layout=None, widget=None):  # noqa: E501
        """DashboardWidgetChild - a model defined in Swagger"""  # noqa: E501
        self._dashboard_widget_id = None
        self._dashboard_widget_name = None
        self._dashboard_widget_refresh_interval = None
        self._dashboard_widget_layout = None
        self._widget = None
        self.discriminator = None
        self.dashboard_widget_id = dashboard_widget_id
        self.dashboard_widget_name = dashboard_widget_name
        if dashboard_widget_refresh_interval is not None:
            self.dashboard_widget_refresh_interval = dashboard_widget_refresh_interval
        self.dashboard_widget_layout = dashboard_widget_layout
        self.widget = widget

    @property
    def dashboard_widget_id(self):
        """Gets the dashboard_widget_id of this DashboardWidgetChild.  # noqa: E501


        :return: The dashboard_widget_id of this DashboardWidgetChild.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_widget_id

    @dashboard_widget_id.setter
    def dashboard_widget_id(self, dashboard_widget_id):
        """Sets the dashboard_widget_id of this DashboardWidgetChild.


        :param dashboard_widget_id: The dashboard_widget_id of this DashboardWidgetChild.  # noqa: E501
        :type: str
        """
        if dashboard_widget_id is None:
            raise ValueError("Invalid value for `dashboard_widget_id`, must not be `None`")  # noqa: E501

        self._dashboard_widget_id = dashboard_widget_id

    @property
    def dashboard_widget_name(self):
        """Gets the dashboard_widget_name of this DashboardWidgetChild.  # noqa: E501


        :return: The dashboard_widget_name of this DashboardWidgetChild.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_widget_name

    @dashboard_widget_name.setter
    def dashboard_widget_name(self, dashboard_widget_name):
        """Sets the dashboard_widget_name of this DashboardWidgetChild.


        :param dashboard_widget_name: The dashboard_widget_name of this DashboardWidgetChild.  # noqa: E501
        :type: str
        """
        if dashboard_widget_name is None:
            raise ValueError("Invalid value for `dashboard_widget_name`, must not be `None`")  # noqa: E501

        self._dashboard_widget_name = dashboard_widget_name

    @property
    def dashboard_widget_refresh_interval(self):
        """Gets the dashboard_widget_refresh_interval of this DashboardWidgetChild.  # noqa: E501


        :return: The dashboard_widget_refresh_interval of this DashboardWidgetChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_refresh_interval

    @dashboard_widget_refresh_interval.setter
    def dashboard_widget_refresh_interval(self, dashboard_widget_refresh_interval):
        """Sets the dashboard_widget_refresh_interval of this DashboardWidgetChild.


        :param dashboard_widget_refresh_interval: The dashboard_widget_refresh_interval of this DashboardWidgetChild.  # noqa: E501
        :type: int
        """

        self._dashboard_widget_refresh_interval = dashboard_widget_refresh_interval

    @property
    def dashboard_widget_layout(self):
        """Gets the dashboard_widget_layout of this DashboardWidgetChild.  # noqa: E501


        :return: The dashboard_widget_layout of this DashboardWidgetChild.  # noqa: E501
        :rtype: LayoutChild
        """
        return self._dashboard_widget_layout

    @dashboard_widget_layout.setter
    def dashboard_widget_layout(self, dashboard_widget_layout):
        """Sets the dashboard_widget_layout of this DashboardWidgetChild.


        :param dashboard_widget_layout: The dashboard_widget_layout of this DashboardWidgetChild.  # noqa: E501
        :type: LayoutChild
        """
        if dashboard_widget_layout is None:
            raise ValueError("Invalid value for `dashboard_widget_layout`, must not be `None`")  # noqa: E501

        self._dashboard_widget_layout = dashboard_widget_layout

    @property
    def widget(self):
        """Gets the widget of this DashboardWidgetChild.  # noqa: E501


        :return: The widget of this DashboardWidgetChild.  # noqa: E501
        :rtype: WidgetChild
        """
        return self._widget

    @widget.setter
    def widget(self, widget):
        """Sets the widget of this DashboardWidgetChild.


        :param widget: The widget of this DashboardWidgetChild.  # noqa: E501
        :type: WidgetChild
        """
        if widget is None:
            raise ValueError("Invalid value for `widget`, must not be `None`")  # noqa: E501

        self._widget = widget

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardWidgetChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardWidgetChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CorporationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'access_level': 'AccessLevel',
        'icon_url': 'str',
        'active': 'bool',
        'created': 'datetime',
        'industry': 'CorporationIndustryChild',
        'locations': 'list[LocationChild]'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'access_level': 'AccessLevel',
        'icon_url': 'IconUrl',
        'active': 'Active',
        'created': 'Created',
        'industry': 'Industry',
        'locations': 'Locations'
    }

    def __init__(self, id=None, name=None, abbreviation=None, access_level=None, icon_url=None, active=None, created=None, industry=None, locations=None):  # noqa: E501
        """CorporationResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._abbreviation = None
        self._access_level = None
        self._icon_url = None
        self._active = None
        self._created = None
        self._industry = None
        self._locations = None
        self.discriminator = None
        self.id = id
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.access_level = access_level
        if icon_url is not None:
            self.icon_url = icon_url
        self.active = active
        self.created = created
        if industry is not None:
            self.industry = industry
        self.locations = locations

    @property
    def id(self):
        """Gets the id of this CorporationResponse.  # noqa: E501


        :return: The id of this CorporationResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CorporationResponse.


        :param id: The id of this CorporationResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this CorporationResponse.  # noqa: E501


        :return: The name of this CorporationResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CorporationResponse.


        :param name: The name of this CorporationResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this CorporationResponse.  # noqa: E501


        :return: The abbreviation of this CorporationResponse.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this CorporationResponse.


        :param abbreviation: The abbreviation of this CorporationResponse.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def access_level(self):
        """Gets the access_level of this CorporationResponse.  # noqa: E501


        :return: The access_level of this CorporationResponse.  # noqa: E501
        :rtype: AccessLevel
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        """Sets the access_level of this CorporationResponse.


        :param access_level: The access_level of this CorporationResponse.  # noqa: E501
        :type: AccessLevel
        """
        if access_level is None:
            raise ValueError("Invalid value for `access_level`, must not be `None`")  # noqa: E501

        self._access_level = access_level

    @property
    def icon_url(self):
        """Gets the icon_url of this CorporationResponse.  # noqa: E501


        :return: The icon_url of this CorporationResponse.  # noqa: E501
        :rtype: str
        """
        return self._icon_url

    @icon_url.setter
    def icon_url(self, icon_url):
        """Sets the icon_url of this CorporationResponse.


        :param icon_url: The icon_url of this CorporationResponse.  # noqa: E501
        :type: str
        """

        self._icon_url = icon_url

    @property
    def active(self):
        """Gets the active of this CorporationResponse.  # noqa: E501


        :return: The active of this CorporationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this CorporationResponse.


        :param active: The active of this CorporationResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def created(self):
        """Gets the created of this CorporationResponse.  # noqa: E501


        :return: The created of this CorporationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this CorporationResponse.


        :param created: The created of this CorporationResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def industry(self):
        """Gets the industry of this CorporationResponse.  # noqa: E501


        :return: The industry of this CorporationResponse.  # noqa: E501
        :rtype: CorporationIndustryChild
        """
        return self._industry

    @industry.setter
    def industry(self, industry):
        """Sets the industry of this CorporationResponse.


        :param industry: The industry of this CorporationResponse.  # noqa: E501
        :type: CorporationIndustryChild
        """

        self._industry = industry

    @property
    def locations(self):
        """Gets the locations of this CorporationResponse.  # noqa: E501


        :return: The locations of this CorporationResponse.  # noqa: E501
        :rtype: list[LocationChild]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this CorporationResponse.


        :param locations: The locations of this CorporationResponse.  # noqa: E501
        :type: list[LocationChild]
        """
        if locations is None:
            raise ValueError("Invalid value for `locations`, must not be `None`")  # noqa: E501

        self._locations = locations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CorporationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CorporationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TagChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tag_id': 'str',
        'tag_name': 'str',
        'tag_category': 'TagCategories'
    }

    attribute_map = {
        'tag_id': 'TagId',
        'tag_name': 'TagName',
        'tag_category': 'TagCategory'
    }

    def __init__(self, tag_id=None, tag_name=None, tag_category=None):  # noqa: E501
        """TagChild - a model defined in Swagger"""  # noqa: E501
        self._tag_id = None
        self._tag_name = None
        self._tag_category = None
        self.discriminator = None
        self.tag_id = tag_id
        self.tag_name = tag_name
        self.tag_category = tag_category

    @property
    def tag_id(self):
        """Gets the tag_id of this TagChild.  # noqa: E501


        :return: The tag_id of this TagChild.  # noqa: E501
        :rtype: str
        """
        return self._tag_id

    @tag_id.setter
    def tag_id(self, tag_id):
        """Sets the tag_id of this TagChild.


        :param tag_id: The tag_id of this TagChild.  # noqa: E501
        :type: str
        """
        if tag_id is None:
            raise ValueError("Invalid value for `tag_id`, must not be `None`")  # noqa: E501

        self._tag_id = tag_id

    @property
    def tag_name(self):
        """Gets the tag_name of this TagChild.  # noqa: E501


        :return: The tag_name of this TagChild.  # noqa: E501
        :rtype: str
        """
        return self._tag_name

    @tag_name.setter
    def tag_name(self, tag_name):
        """Sets the tag_name of this TagChild.


        :param tag_name: The tag_name of this TagChild.  # noqa: E501
        :type: str
        """
        if tag_name is None:
            raise ValueError("Invalid value for `tag_name`, must not be `None`")  # noqa: E501

        self._tag_name = tag_name

    @property
    def tag_category(self):
        """Gets the tag_category of this TagChild.  # noqa: E501


        :return: The tag_category of this TagChild.  # noqa: E501
        :rtype: TagCategories
        """
        return self._tag_category

    @tag_category.setter
    def tag_category(self, tag_category):
        """Sets the tag_category of this TagChild.


        :param tag_category: The tag_category of this TagChild.  # noqa: E501
        :type: TagCategories
        """
        if tag_category is None:
            raise ValueError("Invalid value for `tag_category`, must not be `None`")  # noqa: E501

        self._tag_category = tag_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TagChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MoveFilesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destination_folder_id': 'str',
        'success_count': 'int',
        'error_count': 'int',
        'errors': 'list[FilesError]'
    }

    attribute_map = {
        'destination_folder_id': 'DestinationFolderId',
        'success_count': 'SuccessCount',
        'error_count': 'ErrorCount',
        'errors': 'Errors'
    }

    def __init__(self, destination_folder_id=None, success_count=None, error_count=None, errors=None):  # noqa: E501
        """MoveFilesResponse - a model defined in Swagger"""  # noqa: E501
        self._destination_folder_id = None
        self._success_count = None
        self._error_count = None
        self._errors = None
        self.discriminator = None
        self.destination_folder_id = destination_folder_id
        self.success_count = success_count
        self.error_count = error_count
        self.errors = errors

    @property
    def destination_folder_id(self):
        """Gets the destination_folder_id of this MoveFilesResponse.  # noqa: E501


        :return: The destination_folder_id of this MoveFilesResponse.  # noqa: E501
        :rtype: str
        """
        return self._destination_folder_id

    @destination_folder_id.setter
    def destination_folder_id(self, destination_folder_id):
        """Sets the destination_folder_id of this MoveFilesResponse.


        :param destination_folder_id: The destination_folder_id of this MoveFilesResponse.  # noqa: E501
        :type: str
        """
        if destination_folder_id is None:
            raise ValueError("Invalid value for `destination_folder_id`, must not be `None`")  # noqa: E501

        self._destination_folder_id = destination_folder_id

    @property
    def success_count(self):
        """Gets the success_count of this MoveFilesResponse.  # noqa: E501


        :return: The success_count of this MoveFilesResponse.  # noqa: E501
        :rtype: int
        """
        return self._success_count

    @success_count.setter
    def success_count(self, success_count):
        """Sets the success_count of this MoveFilesResponse.


        :param success_count: The success_count of this MoveFilesResponse.  # noqa: E501
        :type: int
        """
        if success_count is None:
            raise ValueError("Invalid value for `success_count`, must not be `None`")  # noqa: E501

        self._success_count = success_count

    @property
    def error_count(self):
        """Gets the error_count of this MoveFilesResponse.  # noqa: E501


        :return: The error_count of this MoveFilesResponse.  # noqa: E501
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """Sets the error_count of this MoveFilesResponse.


        :param error_count: The error_count of this MoveFilesResponse.  # noqa: E501
        :type: int
        """
        if error_count is None:
            raise ValueError("Invalid value for `error_count`, must not be `None`")  # noqa: E501

        self._error_count = error_count

    @property
    def errors(self):
        """Gets the errors of this MoveFilesResponse.  # noqa: E501


        :return: The errors of this MoveFilesResponse.  # noqa: E501
        :rtype: list[FilesError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this MoveFilesResponse.


        :param errors: The errors of this MoveFilesResponse.  # noqa: E501
        :type: list[FilesError]
        """
        if errors is None:
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MoveFilesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoveFilesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PicturesModelV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'description': 'str',
        'name': 'str',
        'image_file_name': 'str',
        'thumbnail_file_name': 'str',
        'attachment': 'AttachmentModelV3'
    }

    attribute_map = {
        'id': 'Id',
        'description': 'Description',
        'name': 'Name',
        'image_file_name': 'ImageFileName',
        'thumbnail_file_name': 'ThumbnailFileName',
        'attachment': 'Attachment'
    }

    def __init__(self, id=None, description=None, name=None, image_file_name=None, thumbnail_file_name=None, attachment=None):  # noqa: E501
        """PicturesModelV3 - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._description = None
        self._name = None
        self._image_file_name = None
        self._thumbnail_file_name = None
        self._attachment = None
        self.discriminator = None
        self.id = id
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if image_file_name is not None:
            self.image_file_name = image_file_name
        if thumbnail_file_name is not None:
            self.thumbnail_file_name = thumbnail_file_name
        if attachment is not None:
            self.attachment = attachment

    @property
    def id(self):
        """Gets the id of this PicturesModelV3.  # noqa: E501


        :return: The id of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PicturesModelV3.


        :param id: The id of this PicturesModelV3.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def description(self):
        """Gets the description of this PicturesModelV3.  # noqa: E501


        :return: The description of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PicturesModelV3.


        :param description: The description of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this PicturesModelV3.  # noqa: E501


        :return: The name of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PicturesModelV3.


        :param name: The name of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def image_file_name(self):
        """Gets the image_file_name of this PicturesModelV3.  # noqa: E501


        :return: The image_file_name of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._image_file_name

    @image_file_name.setter
    def image_file_name(self, image_file_name):
        """Sets the image_file_name of this PicturesModelV3.


        :param image_file_name: The image_file_name of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._image_file_name = image_file_name

    @property
    def thumbnail_file_name(self):
        """Gets the thumbnail_file_name of this PicturesModelV3.  # noqa: E501


        :return: The thumbnail_file_name of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_file_name

    @thumbnail_file_name.setter
    def thumbnail_file_name(self, thumbnail_file_name):
        """Sets the thumbnail_file_name of this PicturesModelV3.


        :param thumbnail_file_name: The thumbnail_file_name of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._thumbnail_file_name = thumbnail_file_name

    @property
    def attachment(self):
        """Gets the attachment of this PicturesModelV3.  # noqa: E501


        :return: The attachment of this PicturesModelV3.  # noqa: E501
        :rtype: AttachmentModelV3
        """
        return self._attachment

    @attachment.setter
    def attachment(self, attachment):
        """Sets the attachment of this PicturesModelV3.


        :param attachment: The attachment of this PicturesModelV3.  # noqa: E501
        :type: AttachmentModelV3
        """

        self._attachment = attachment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PicturesModelV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PicturesModelV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SystemAssetsStatusSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'system': 'SystemChild',
        'asset_count': 'int',
        'status_count': 'AssetsStatusCountChild',
        'status_percentage': 'AssetsStatusPercentageChild'
    }

    attribute_map = {
        'system': 'System',
        'asset_count': 'AssetCount',
        'status_count': 'StatusCount',
        'status_percentage': 'StatusPercentage'
    }

    def __init__(self, system=None, asset_count=None, status_count=None, status_percentage=None):  # noqa: E501
        """SystemAssetsStatusSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._system = None
        self._asset_count = None
        self._status_count = None
        self._status_percentage = None
        self.discriminator = None
        self.system = system
        self.asset_count = asset_count
        self.status_count = status_count
        if status_percentage is not None:
            self.status_percentage = status_percentage

    @property
    def system(self):
        """Gets the system of this SystemAssetsStatusSummaryResponse.  # noqa: E501


        :return: The system of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :rtype: SystemChild
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this SystemAssetsStatusSummaryResponse.


        :param system: The system of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :type: SystemChild
        """
        if system is None:
            raise ValueError("Invalid value for `system`, must not be `None`")  # noqa: E501

        self._system = system

    @property
    def asset_count(self):
        """Gets the asset_count of this SystemAssetsStatusSummaryResponse.  # noqa: E501


        :return: The asset_count of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._asset_count

    @asset_count.setter
    def asset_count(self, asset_count):
        """Sets the asset_count of this SystemAssetsStatusSummaryResponse.


        :param asset_count: The asset_count of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :type: int
        """
        if asset_count is None:
            raise ValueError("Invalid value for `asset_count`, must not be `None`")  # noqa: E501

        self._asset_count = asset_count

    @property
    def status_count(self):
        """Gets the status_count of this SystemAssetsStatusSummaryResponse.  # noqa: E501


        :return: The status_count of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :rtype: AssetsStatusCountChild
        """
        return self._status_count

    @status_count.setter
    def status_count(self, status_count):
        """Sets the status_count of this SystemAssetsStatusSummaryResponse.


        :param status_count: The status_count of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :type: AssetsStatusCountChild
        """
        if status_count is None:
            raise ValueError("Invalid value for `status_count`, must not be `None`")  # noqa: E501

        self._status_count = status_count

    @property
    def status_percentage(self):
        """Gets the status_percentage of this SystemAssetsStatusSummaryResponse.  # noqa: E501


        :return: The status_percentage of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :rtype: AssetsStatusPercentageChild
        """
        return self._status_percentage

    @status_percentage.setter
    def status_percentage(self, status_percentage):
        """Sets the status_percentage of this SystemAssetsStatusSummaryResponse.


        :param status_percentage: The status_percentage of this SystemAssetsStatusSummaryResponse.  # noqa: E501
        :type: AssetsStatusPercentageChild
        """

        self._status_percentage = status_percentage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SystemAssetsStatusSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemAssetsStatusSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardWidgetRequestChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dashboard_widget_id': 'str',
        'dashboard_widget_row': 'int',
        'dashboard_widget_column': 'int',
        'dashboard_widget_height': 'int',
        'dashboard_widget_width': 'int'
    }

    attribute_map = {
        'dashboard_widget_id': 'DashboardWidgetId',
        'dashboard_widget_row': 'DashboardWidgetRow',
        'dashboard_widget_column': 'DashboardWidgetColumn',
        'dashboard_widget_height': 'DashboardWidgetHeight',
        'dashboard_widget_width': 'DashboardWidgetWidth'
    }

    def __init__(self, dashboard_widget_id=None, dashboard_widget_row=None, dashboard_widget_column=None, dashboard_widget_height=None, dashboard_widget_width=None):  # noqa: E501
        """DashboardWidgetRequestChild - a model defined in Swagger"""  # noqa: E501
        self._dashboard_widget_id = None
        self._dashboard_widget_row = None
        self._dashboard_widget_column = None
        self._dashboard_widget_height = None
        self._dashboard_widget_width = None
        self.discriminator = None
        self.dashboard_widget_id = dashboard_widget_id
        self.dashboard_widget_row = dashboard_widget_row
        self.dashboard_widget_column = dashboard_widget_column
        self.dashboard_widget_height = dashboard_widget_height
        self.dashboard_widget_width = dashboard_widget_width

    @property
    def dashboard_widget_id(self):
        """Gets the dashboard_widget_id of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_id of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_widget_id

    @dashboard_widget_id.setter
    def dashboard_widget_id(self, dashboard_widget_id):
        """Sets the dashboard_widget_id of this DashboardWidgetRequestChild.


        :param dashboard_widget_id: The dashboard_widget_id of this DashboardWidgetRequestChild.  # noqa: E501
        :type: str
        """
        if dashboard_widget_id is None:
            raise ValueError("Invalid value for `dashboard_widget_id`, must not be `None`")  # noqa: E501

        self._dashboard_widget_id = dashboard_widget_id

    @property
    def dashboard_widget_row(self):
        """Gets the dashboard_widget_row of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_row of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_row

    @dashboard_widget_row.setter
    def dashboard_widget_row(self, dashboard_widget_row):
        """Sets the dashboard_widget_row of this DashboardWidgetRequestChild.


        :param dashboard_widget_row: The dashboard_widget_row of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_row is None:
            raise ValueError("Invalid value for `dashboard_widget_row`, must not be `None`")  # noqa: E501

        self._dashboard_widget_row = dashboard_widget_row

    @property
    def dashboard_widget_column(self):
        """Gets the dashboard_widget_column of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_column of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_column

    @dashboard_widget_column.setter
    def dashboard_widget_column(self, dashboard_widget_column):
        """Sets the dashboard_widget_column of this DashboardWidgetRequestChild.


        :param dashboard_widget_column: The dashboard_widget_column of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_column is None:
            raise ValueError("Invalid value for `dashboard_widget_column`, must not be `None`")  # noqa: E501

        self._dashboard_widget_column = dashboard_widget_column

    @property
    def dashboard_widget_height(self):
        """Gets the dashboard_widget_height of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_height of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_height

    @dashboard_widget_height.setter
    def dashboard_widget_height(self, dashboard_widget_height):
        """Sets the dashboard_widget_height of this DashboardWidgetRequestChild.


        :param dashboard_widget_height: The dashboard_widget_height of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_height is None:
            raise ValueError("Invalid value for `dashboard_widget_height`, must not be `None`")  # noqa: E501

        self._dashboard_widget_height = dashboard_widget_height

    @property
    def dashboard_widget_width(self):
        """Gets the dashboard_widget_width of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_width of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_width

    @dashboard_widget_width.setter
    def dashboard_widget_width(self, dashboard_widget_width):
        """Sets the dashboard_widget_width of this DashboardWidgetRequestChild.


        :param dashboard_widget_width: The dashboard_widget_width of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_width is None:
            raise ValueError("Invalid value for `dashboard_widget_width`, must not be `None`")  # noqa: E501

        self._dashboard_widget_width = dashboard_widget_width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardWidgetRequestChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardWidgetRequestChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
